civic\_scraper.platforms package
================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   civic_scraper.platforms.civic_plus

Submodules
----------

civic\_scraper.platforms.granicus module
----------------------------------------

.. automodule:: civic_scraper.platforms.granicus
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: civic_scraper.platforms
   :members:
   :undoc-members:
   :show-inheritance:
